@@ -13,33 +13,27 @@
 /// @author Tiago Quintino
 /// @date   April 2016
 
-#ifndef metkit_TypeAny_H
-#define metkit_TypeAny_H
+#pragma once
 
 #include "metkit/mars/Type.h"
 
-namespace metkit {
-namespace mars {
+namespace metkit::mars {
 
 //----------------------------------------------------------------------------------------------------------------------
 
 class TypeAny : public Type {
 
-public: // methods
+public:  // methods
 
-    TypeAny(const std::string &name, const eckit::Value& settings = eckit::Value());
+    TypeAny(const std::string& name, const eckit::Value& settings = eckit::Value());
 
     virtual ~TypeAny() override;
 
-private: // methods
-
-    virtual void print(std::ostream &out) const override;
-    virtual bool expand(const MarsExpandContext& ctx, std::string &value) const override;
+private:  // methods
 
+    virtual void print(std::ostream& out) const override;
+    virtual bool expand(const MarsExpandContext& ctx, std::string& value) const override;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
-} // namespace mars
-} // namespace metkit
-
-#endif
+}  // namespace metkit::mars
