@@ -13,28 +13,26 @@
 /// @author Tiago Quintino
 /// @date   April 2016
 
-#ifndef metkit_TypeEnum_H
-#define metkit_TypeEnum_H
+#pragma once
 
 #include "metkit/mars/Type.h"
 
-namespace metkit {
-namespace mars {
+namespace metkit::mars {
 
 //----------------------------------------------------------------------------------------------------------------------
 
 class TypeEnum : public Type {
 
-public: // methods
+public:  // methods
 
-    TypeEnum(const std::string &name, const eckit::Value& settings);
+    TypeEnum(const std::string& name, const eckit::Value& settings);
 
     virtual ~TypeEnum() override;
 
 
-private: // methods
+private:  // methods
 
-    virtual void print( std::ostream &out ) const override;
+    virtual void print(std::ostream& out) const override;
     virtual void reset() override;
     virtual bool expand(const MarsExpandContext& ctx, std::string& value) const override;
 
@@ -42,12 +40,8 @@ private: // methods
     std::vector<std::string> values_;
 
     mutable std::map<std::string, std::string> cache_;
-
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace mars
-} // namespace metkit
-
-#endif
+}  // namespace metkit::mars
