@@ -8,7 +8,7 @@
  * does it submit to any jurisdiction.
  */
 
-/// @file   TypeToByListQuantile.h
+/// @file   TypeRange.h
 /// @author Emanuele Danovaro
 /// @date   February 2022
 
@@ -16,36 +16,28 @@
 
 #include "metkit/mars/Type.h"
 
-namespace metkit {
-namespace mars {
+namespace metkit::mars {
 
 class StepRange;
+
 //----------------------------------------------------------------------------------------------------------------------
 
 class TypeRange : public Type {
 
-public: // methods
+public:  // methods
 
-    TypeRange(const std::string &name, const eckit::Value& settings);
+    TypeRange(const std::string& name, const eckit::Value& settings);
 
     virtual ~TypeRange() override;
 
-private: // methods
+private:  // methods
 
-    virtual void print( std::ostream &out ) const override;
+    virtual void print(std::ostream& out) const override;
     virtual bool expand(const MarsExpandContext& ctx, std::string& value) const override;
-    virtual void expand(const MarsExpandContext& ctx,
-                        std::vector<std::string>& values) const override;
 
     StepRange parse(std::string& value) const;
-
-private: // attributes
-
-    eckit::Time by_;
-
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace mars
-} // namespace metkit
+}  // namespace metkit::mars
