@@ -14,34 +14,28 @@
 
 #pragma once
 
+#include "metkit/mars/Quantile.h"
 #include "metkit/mars/Type.h"
-
-namespace metkit {
-namespace mars {
+namespace metkit::mars {
 
 //----------------------------------------------------------------------------------------------------------------------
 
 class TypeToByListQuantile : public Type {
 
-public: // methods
+public:  // methods
 
-    TypeToByListQuantile(const std::string &name, const eckit::Value& settings);
+    TypeToByListQuantile(const std::string& name, const eckit::Value& settings);
 
     virtual ~TypeToByListQuantile() override;
 
-private: // methods
+private:  // methods
 
-    virtual void print( std::ostream &out ) const override;
+    virtual void print(std::ostream& out) const override;
     virtual bool expand(const MarsExpandContext& ctx, std::string& value) const override;
-    virtual void expand(const MarsExpandContext& ctx,
-                        std::vector<std::string>& values) const override;
 
     std::set<long> denominators_;
-    long by_;
-
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace mars
-} // namespace metkit
+}  // namespace metkit::mars
